# Contribution guidelines

- When you add a `keras` model, please save the architecture and weights in `<model-name>.json` and `<model-name>_weights.h5` files.

- If you have example **data** you want to add, please save them in `data/` with names `<model-name>_input.dat` and `<model-name>_output.dat`.

- If you have example **configuration** you want to add, please save them in `config-files/` with names `<model-name>_config.yml`
